@@ -39,7 +39,7 @@ from datetime import datetime, timedelta
 import pytz
 from requests import Session
 
-from opsgenielib.opsgenielibexceptions import InvalidApiKey
+from opsgenielib.opsgenielibexceptions import InvalidApiKey, NoAlertPolicyFound
 
 __author__ = '''Yorick Hoorneman <yhoorneman@schubergphilis.com>'''
 __docformat__ = '''google'''
@@ -100,18 +100,21 @@ class Team:
             response.raise_for_status()
         return [Integration(self, integration) for integration in response.json().get('data', {})]
 
-
-class AlertPolicy:
-    """Models the Alert Policy."""
+class Policy:
 
     def __init__(self, server, data):
-        self._logger = logging.getLogger(f'{LOGGER_BASENAME}.{self.__class__.__name__}')
         self._server = server
         self._data = data
 
     @property
     def id(self):  # pylint: disable=invalid-name, missing-docstring
         return self._data.get('id')
+
+class AlertPolicy(Policy):
+    """Models the Alert Policy."""
+
+    def __init__(self, server, data):
+        super().__init__(server, data)
     
     @property
     def continue_after(self):  # pylint: disable=invalid-name, missing-docstring
@@ -156,6 +159,24 @@ class AlertPolicy:
     @property
     def details(self):  # pylint: disable=missing-docstring
         return self._data.get('details')
+    
+class MaintenancePolicy(Policy):
+    """Models the Maintenance Policy."""
+
+    def __init__(self, server, data):
+        super().__init__(server, data)
+
+    @property
+    def status(self):  # pylint: disable=missing-docstring
+        return self._data.get('status')
+
+    @property
+    def description(self):  # pylint: disable=missing-docstring
+        return self._data.get('description')
+    
+    @property
+    def time(self):  # pylint: disable=missing-docstring
+        return self._data.get('time')
 
 class Integration:
     """Models the integration."""
@@ -293,6 +314,16 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
             response.raise_for_status()
         return response
 
+    def set_maintenance_hours_by_name(self,  # pylint: disable=too-many-arguments, too-many-locals
+                              team_id,
+                              hours,
+                              rule_type,
+                              description,
+                              state,
+                              policy_name):
+        policy = self.get_alert_policy_by_name(policy_name, team_id)
+        return self.set_maintenance_hours(team_id, hours, rule_type, description, state, policy.id)
+
     def set_maintenance_hours(self,  # pylint: disable=too-many-arguments, too-many-locals
                               team_id,
                               hours,
@@ -346,7 +377,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         self._logger.debug('Making a call to "%s"', url)
         response = self._session.get(url, params=params)
         response.raise_for_status()
-        return response.json()
+        return [MaintenancePolicy(self, policy) for policy in response.json().get('data', {})]
 
     def cancel_maintenance(self, maintenance_id):
         """Cancel a maintenance policy. ID of the maintenance policy is mandatory."""
@@ -483,6 +514,12 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         response = self._session.get(url, params=parameters)
         response.raise_for_status()
         return AlertPolicy(self, response.json().get('data', {}))
+        
+    def get_alert_policy_by_name(self, policy_name, team_id):
+        alert_policy = [policy for policy in self.list_alert_policy(team_id) if policy.name == policy_name]
+        if not alert_policy:
+            raise NoAlertPolicyFound
+        return next(iter(alert_policy))
 
     def list_alert_policy(self, team_id):
         """Listing all alert policies. Specify the team id."""
